@@ -1,8 +1,8 @@
 from dataclasses import dataclass
 from typing import Optional
 
-from .interfaces import CommandRunner, GithubRepository
-from .list_remote import ListRemote
+from nix_prefetch_github.interfaces import CommandRunner, GithubRepository
+from nix_prefetch_github.list_remote import ListRemote
 
 
 @dataclass(frozen=True)
