@@ -1,8 +1,9 @@
-from dataclasses import dataclass
-from sys import exit
-from typing import Optional
+from __future__ import annotations
 
-from ..interfaces import (
+from dataclasses import dataclass
+from typing import Optional, Protocol
+
+from nix_prefetch_github.interfaces import (
     GithubRepository,
     Prefetcher,
     PrefetchOptions,
@@ -11,6 +12,18 @@ from ..interfaces import (
 )
 
 
+class Alerter(Protocol):
+    def alert_user_about_unsafe_prefetch_options(
+        self, prefetch_options: PrefetchOptions
+    ) -> None:
+        ...
+
+
+class PrefetchGithubRepositoryUseCase(Protocol):
+    def prefetch_github_repository(self, request: Request) -> None:
+        ...
+
+
 @dataclass
 class Request:
     repository: GithubRepository
@@ -20,18 +33,26 @@ class Request:
 
 
 @dataclass
-class PrefetchGithubRepositoryUseCase:
+class PrefetchGithubRepositoryUseCaseImpl:
     nix_presenter: Presenter
     json_presenter: Presenter
     prefetcher: Prefetcher
+    alerter: Alerter
 
     def prefetch_github_repository(self, request: Request) -> None:
+        if (
+            request.prefetch_options.leave_dot_git
+            or request.prefetch_options.deep_clone
+        ):
+            self.alerter.alert_user_about_unsafe_prefetch_options(
+                request.prefetch_options
+            )
         prefetch_result = self.prefetcher.prefetch_github(
             repository=request.repository,
             rev=request.revision,
             prefetch_options=request.prefetch_options,
         )
         if request.rendering_format == RenderingFormat.json:
-            exit(self.json_presenter.present(prefetch_result))
+            self.json_presenter.present(prefetch_result)
         else:
-            exit(self.nix_presenter.present(prefetch_result))
+            self.nix_presenter.present(prefetch_result)
