@@ -66,22 +66,6 @@ class NixEvaluationTests(TestCase):
                 "--nix",
                 "-v",
             ],
-            [
-                f"{self.output}/bin/nix-prefetch-github",
-                "seppeljordan",
-                "nix-prefetch-github",
-                "--nix",
-                "--leave-dot-git",
-                "-v",
-            ],
-            [
-                f"{self.output}/bin/nix-prefetch-github",
-                "NixOS",
-                "nixpkgs",
-                "--nix",
-                "--deep-clone",
-                "-v",
-            ],
         ]
         for expression in expressions:
             with self.subTest(msg=shlex.join(expression)):
